#
# spec file for package python-pyocr
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define sha ca191ba776743fe10a1c3dd99eaa82626ee4edc1
%{?sle15_python_module_pythons}
Name:           python-pyocr
Version:        0.8.5
Release:        1.3
Summary:        Python wrapper for OCR engines
License:        GPL-3.0-or-later
Group:          Development/Languages/Python
URL:            https://gitlab.gnome.org/World/OpenPaperwork/pyocr
Source:         https://gitlab.gnome.org/World/OpenPaperwork/pyocr/-/archive/%{version}/%{name}-%{version}.tar.gz
BuildRequires:  %{python_module Pillow}
BuildRequires:  %{python_module base}
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module setuptools_scm}
BuildRequires:  %{python_module setuptools}
BuildRequires:  %{python_module wheel}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       python-Pillow
Recommends:     cuneiform
Recommends:     tesseract-ocr
BuildArch:      noarch
%python_subpackages

%description
PyOCR is an optical character recognition (OCR) tool wrapper for python.
That is, it helps using various OCR tools from a Python program.

%prep
%setup -q -n pyocr-%{version}-%{sha}

%build
%pyproject_wheel

%install
%pyproject_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%files %{python_files}
%license COPYING
%doc AUTHORS ChangeLog README.md
%{python_sitelib}/pyocr
%{python_sitelib}/pyocr-%{version}.dist-info

%changelog
* Tue Jan  2 2024 Dirk Müller <dmueller@suse.com>
- update to 0.8.5:
  * Fix LineBoxBuilder: Take into account headers and footers
    too, not just the body.
  * switch from setup.py to pyproject.toml
  * switch from tox to pytest
* Wed Jan  4 2023 Dirk Müller <dmueller@suse.com>
- update to 0.8.3:
  * Workaround https://github.com/pypa/setuptools_scm/issues/727
  * Add support for Tesseravt 5 + Linux
  * Fix file descriptor leak (thanks to oda)
  * Make the dependency on setuptools_scm optional
* Thu Aug 26 2021 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to 0.8:
  * Replaced libtesseract.image_to_pdf() by an object-oriented API that allows
    creating PDF with more than 1 page (thanks to Matthias Kraus).
  * Tesseract 4 + sys.frozen=True: Fix TESSDATA_PREFIX: starting with
    Tesseract 4, the path must include tessdata/
* Tue Sep 10 2019 Tomáš Chvátal <tchvatal@suse.com>
- Update to 0.7.2:
  * minor bugfixes
* Thu May 16 2019 Hardik Italia <hitalia@suse.com>
- Update to vetison 0.7:
  * Drop support for Python <= 2.7
  * Fix: Make sure the builder objects can be used to parse box files
    even if Tesseract is not installed.
  * PyOCR version is now automatically set in the module by setuptools_scm
    instead of PyOCR's Makefile (except on Windows)
  * Tesseract: optim: keep the get_version() in memory instead of calling
    Tesseract everytime (get_version() by psm_parameter() which is called each
    time a box file is parsed ...)
- Update project url and source to gitlab
* Tue Dec 26 2017 mpluskal@suse.com
- Update to version 0.5:
  * Tesseract/Libtesseract + LineBoxBuilder: Add confidence scores
    to every word boxes and to hOCR files (thanks to Adriano Pagano)
  * Tesseract 4 (shell): Add '--oem 0' to specify legacy model when
    doing orientation detection as orientation detection does not
    work yet with Tesseract 4 (thanks to Adriano Pagano)
  * Libtesseract: Fix multi-language support
  * Tesseract (shell) + Windows: Never let the cmd window appear
  * Libtesseract: Implements image_to_pdf() (thanks to Marian Skrip)
  * Libtesseract: Hide debug messages (thanks to Ashish Kulkarni)
- Update project url and use github sources
* Fri Dec 15 2017 mvetter@suse.com
- Use python singlespec
* Wed Oct  5 2016 mailaender@opensuse.org
- update to version 0.4.1
* Sun Aug 10 2014 jw@owncloud.com
- v0.2.3 initial pull from pypi
